@@ -5,4 +5,4 @@ from ..models.account import AccountClosure
 
 @admin.register(AccountClosure)
 class AccountClosureAdmin(admin.ModelAdmin):
-    list_display = ('closure_date',)
+    list_display = ("closure_date",)
