@@ -1,12 +1,11 @@
 from datetime import date, datetime
 
 import pytz
-from django.http import HttpResponse, JsonResponse
+from django.http import JsonResponse
 from django.shortcuts import get_object_or_404
 from django.utils.timezone import localdate
 
 from ..models.journals import Journal
-from ..rocketchat import RocketChat, get_rc_id
 from ..views import leader_or_staff_required
 
 
@@ -27,16 +26,3 @@ def participants(request, journal_id):
             "participants": list({"value": p.id, "label": str(p)} for p in journal.get_valid_participants(d)),
         }
     )
-
-
-def rocketchat(request):
-    """
-    Implements API for Rocket.Chat IFrame authentication
-    """
-    if not request.user.is_authenticated():
-        return HttpResponse(status=401)
-
-    rc = RocketChat()
-    rc.sync_user(request.user)
-
-    return JsonResponse({"loginToken": rc.create_login_token(get_rc_id(request.user))})
