@@ -7,8 +7,8 @@ class ConfirmForm(FormMixin, forms.Form):
     answer = forms.BooleanField()
 
     def __init__(self, *args, **kwargs):
-        self.instance = kwargs.pop('instance', None)
-        super(ConfirmForm, self).__init__(*args, **kwargs)
+        self.instance = kwargs.pop("instance", None)
+        super().__init__(*args, **kwargs)
 
     def save(self):
         return self.instance
