@@ -39,7 +39,10 @@ urlpatterns = [
     d_url(r"^{password_reset}/complete/$", "password_reset_complete"),
     d_url(r"^{leader}/$", "leader_summary"),
     d_url(r"^{leader}/{journal}/(?P<pk>[0-9]+)/$", "journal"),
-    d_url(r"^{leader}/{journal}/{journalentry}/{add}/(?P<subject>[0-9]+)/$", "journalentry_create"),
+    d_url(r"^{leader}/{journal}/{add}/(?P<subject>[0-9]+)/$", "journal_create"),
+    d_url(r"^{leader}/{journal}/(?P<pk>[0-9]+)/{edit}/$", "journal_update"),
+    d_url(r"^{leader}/{journal}/(?P<pk>[0-9]+)/{delete}/$", "journal_delete"),
+    d_url(r"^{leader}/{journal}/{journalentry}/{add}/(?P<journal>[0-9]+)/$", "journalentry_create"),
     d_url(r"^{leader}/{journal}/{journalentry}/(?P<pk>[0-9]+)/$", "journalentry_update"),
     d_url(r"^{leader}/{journal}/{journalentry}/(?P<pk>[0-9]+)/{delete}/$", "journalentry_delete"),
     d_url(r"^{leader}/{journal}/{alternating}/$", "alternating"),
@@ -53,6 +56,7 @@ urlpatterns = [
     d_url(r"^{leader}/{timesheets}/{journalentry}/(?P<pk>[0-9]+)/{delete}/$", "journalleaderentry_delete"),
     d_url(r"^{leader}/(?P<subject_type>[^/]+)/$", "subject_list_mine"),
     d_url(r"^{leader}/(?P<subject_type>[^/]+)/(?P<pk>[0-9]+)/{edit}/$", "subject_update"),
+    d_url(r"^{leader}/(?P<subject_type>[^/]+)/(?P<pk>[0-9]+)/{journals}/$", "subject_journals"),
     d_url(r"^{leader}/(?P<subject_type>[^/]+)/(?P<pk>[0-9]+)/{registrations}/$", "subject_registrations"),
     d_url(r"^{registrations}/$", "registration_list"),
     d_url(
